@@ -12,11 +12,10 @@
 #include <stdlib.h>
 
 #include <QPainter>
-#include <QPixmap>
 #include <QMouseEvent>
 #include <QStyleOptionViewItem>
 
-#include <KRandom>
+#include <QRandomGenerator>
 #include <QStandardPaths>
 
 
@@ -216,7 +215,7 @@ bool dicesWidget::generateDices()
 	{
 		if (m_rollDice[i])
 		{
-			m_dice[i] = 1 + (int)(6.0 * KRandom::random() / (RAND_MAX + 1.0));
+			m_dice[i] = 1 + QRandomGenerator::global()->bounded(6);
 			m_rollDice[i] = false;
 			any = true;
 		}
